@@ -25,7 +25,7 @@ NULL
 #' @section Objects from the Class:
 #' Objects can be created by calls of the form `set_RLum("RLum.Analysis", ...)`.
 #'
-#' @section Class version: 0.4.16
+#' @section Class version: 0.4.17
 #'
 #' @author
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
@@ -349,12 +349,13 @@ setMethod(
 #' @export
 setMethod("get_RLum",
           signature = ("RLum.Analysis"),
-
           function(object, record.id = NULL, recordType = NULL, curveType = NULL, RLum.type = NULL,
-                   protocol = "UNKNOWN", get.index = NULL, drop = TRUE, recursive = TRUE, info.object = NULL, subset = NULL, env = parent.frame(2)) {
+                   protocol = "UNKNOWN", get.index = NULL, drop = TRUE, recursive = TRUE,
+                   info.object = NULL, subset = NULL, env = parent.frame(2)) {
+            .set_function_name("get_RLum")
+            on.exit(.unset_function_name(), add = TRUE)
 
             if (!is.null(substitute(subset))) {
-
               # To account for different lengths and elements in the @info slot we first
               # check all unique elements (in all records)
               info_el <- unique(unlist(lapply(object@records, function(el) names(el@info))))
@@ -384,12 +385,11 @@ setMethod("get_RLum",
               ),
               error = function(e) {
                 .throw_error("Invalid subset expression, valid terms are: ",
-                             paste(names(envir), collapse = ", "), nframe = 6)
+                             paste(names(envir), collapse = ", "))
               })
 
               if (!is.logical(sel)) {
-                .throw_error("'subset' must contain a logical expression",
-                             nframe = 2)
+                .throw_error("'subset' must contain a logical expression")
               }
 
               if (all(is.na(sel)))
@@ -417,12 +417,10 @@ setMethod("get_RLum",
                 ##check for entries
                 if(length(object@info) == 0){
                   .throw_warning("This 'RLum.Analysis' object has no info ",
-                                 "objects, NULL returned",
-                                 nframe = 3)
+                                 "objects, NULL returned")
                 }else{
                   .throw_warning("Invalid 'info.object' name, valid names are: ",
-                                 paste(names(object@info), collapse = ", "),
-                                 nframe = 3)
+                                 paste(names(object@info), collapse = ", "))
                 }
                 return(NULL)
               }
@@ -431,9 +429,8 @@ setMethod("get_RLum",
 
               ##check for records
               if (length(object@records) == 0) {
-
                 .throw_warning("This 'RLum.Analysis' object has no records, ",
-                               "NULL returned", nframe = 3)
+                               "NULL returned")
                 return(NULL)
               }
 
@@ -444,7 +441,7 @@ setMethod("get_RLum",
               } else if (!is.numeric(record.id) &
                          !is.logical(record.id)) {
                 .throw_error("'record.id' has to be of type 'numeric' or ",
-                             "'logical'", nframe = 3)
+                             "'logical'")
               }
               ##logical needs a slightly different treatment
               ##Why do we need this? Because a lot of standard R functions work with logical
@@ -468,8 +465,7 @@ setMethod("get_RLum",
                     x@recordType, character(1)))
 
               } else if (!inherits(recordType, "character")){
-                .throw_error("'recordType' has to be of type 'character'",
-                             nframe = 3)
+                .throw_error("'recordType' has to be of type 'character'")
               }
 
               ##curveType
@@ -480,8 +476,7 @@ setMethod("get_RLum",
                                                   })))
 
               } else if (!is(curveType, "character")) {
-                .throw_error("'curveType' has to be of type 'character'",
-                             nframe = 3)
+                .throw_error("'curveType' has to be of type 'character'")
               }
 
               ##RLum.type
@@ -489,8 +484,7 @@ setMethod("get_RLum",
                 RLum.type <- c("RLum.Data.Curve", "RLum.Data.Spectrum", "RLum.Data.Image")
 
               } else if (!is(RLum.type, "character")) {
-                .throw_error("'RLum.type' has to be of type 'character'",
-                             nframe = 3)
+                .throw_error("'RLum.type' has to be of type 'character'")
               }
 
               ##get.index
@@ -498,8 +492,7 @@ setMethod("get_RLum",
                 get.index <- FALSE
 
               } else if (!is(get.index, "logical")) {
-                .throw_error("'get.index' has to be of type 'logical'",
-                             nframe = 3)
+                .throw_error("'get.index' has to be of type 'logical'")
               }
 
               ##get originator
@@ -516,29 +509,32 @@ setMethod("get_RLum",
               record.id <- 1:length(object@records)
 
               ##select curves according to the chosen parameter
-              if (length(record.id) > 1) {
+              if (length(record.id) >= 1) {
                 temp <- lapply(record.id, function(x) {
-                  if (is(object@records[[x]])[1] %in% RLum.type == TRUE) {
-                    ##as input a vector is allowed
+                  if (is(object@records[[x]])[1] %in% RLum.type) {
+                      ##as input a vector is allowed
                     temp <- lapply(1:length(recordType), function(k) {
                       ##translate input to regular expression
                       recordType[k] <- glob2rx(recordType[k])
                       recordType[k] <- substr(recordType[k], start = 2, stop = nchar(recordType[k]) - 1)
 
-                      if (grepl(recordType[k], object@records[[x]]@recordType) == TRUE &
+                      ##handle NA
+                      if(is.na(object@records[[x]]@recordType))
+                        recordType_comp <- "NA"
+                      else
+                        recordType_comp <- object@records[[x]]@recordType
+
+                      ## get the results object and if requested, get the index
+                      if (grepl(recordType[k], recordType_comp) &
                           object@records[[x]]@curveType %in% curveType) {
-                        if (!get.index) {
-                          object@records[[x]]
+                        if (!get.index) object@records[[x]] else x
 
-                        } else{
-                          x
-                        }
                       }
 
                     })
 
                     ##remove empty entries and select just one to unlist
-                    temp <- temp[!sapply(temp, is.null)]
+                    temp <- temp[!vapply(temp, is.null,logical(1))]
 
                     ##if list has length 0 skip entry
                     if (length(temp) != 0) {
@@ -549,21 +545,18 @@ setMethod("get_RLum",
                   }
                 })
 
-
                 ##remove empty list element
-                temp <- temp[!sapply(temp, is.null)]
+                temp <- temp[!vapply(temp, is.null, logical(1))]
 
                 ##check if the produced object is empty and show warning message
                 if (length(temp) == 0)
-                  .throw_warning("This request produced an empty list of records",
-                                 nframe = 3)
+                  .throw_warning("This request produced an empty list of records")
 
                 ##remove list for get.index
                 if (get.index) {
                   return(unlist(temp))
 
                 } else{
-
                   if (!drop) {
                     temp <- set_RLum(
                       class = "RLum.Analysis",
@@ -586,7 +579,7 @@ setMethod("get_RLum",
                 }
 
               } else{
-                if (get.index == FALSE) {
+                if (!get.index[1]) {
                   if (drop == FALSE) {
                     ##needed to keep the argument drop == TRUE
                     temp <- set_RLum(
@@ -632,6 +625,8 @@ setMethod("get_RLum",
 setMethod("structure_RLum",
           signature= "RLum.Analysis",
           definition = function(object, fullExtent = FALSE) {
+            .set_function_name("structure_RLum")
+            on.exit(.unset_function_name(), add = TRUE)
 
             ##check if the object containing other elements than allowed
             if(!all(vapply(object@records, FUN = class, character(1)) == "RLum.Data.Curve"))
