@@ -260,7 +260,9 @@ fit_LMCurve<- function(
   plot = TRUE,
   plot.BG = FALSE,
   ...
-){
+) {
+  .set_function_name("fit_LMCurve")
+  on.exit(.unset_function_name(), add = TRUE)
 
   # (0) Integrity checks -------------------------------------------------------
 
@@ -339,7 +341,7 @@ fit_LMCurve<- function(
 
   # layout safety settings
   par.default <- par()[c("mfrow", "cex", "mar", "omi", "oma")]
-  on.exit(par(par.default))
+  on.exit(par(par.default), add = TRUE)
 
   ##============================================================================##
   ##  BACKGROUND SUBTRACTION
