@@ -262,19 +262,15 @@ fit_ThermalQuenching <- function(
         return(NULL)
       } else{
         temp
-
       }
-
     })
 
   }else{
-    try(stop("[fit_ThermalQuenching()] Fitting failed, NULL returned!", call. = FALSE), silent = FALSE)
+    message("[fit_ThermalQuenching()] Error: Fitting failed, NULL returned!")
     return(NULL)
-
-
   }
 
-  ##remove NULL (the fit was not sucessfull)
+  ## remove NULL (the fit was not successful)
   fit_MC <- fit_MC[!sapply(X = fit_MC, is.null)]
   n.MC <- length(fit_MC)
 
