@@ -50,6 +50,8 @@
 get_Layout <- function(
   layout
 ) {
+  .set_function_name("get_Layout")
+  on.exit(.unset_function_name(), add = TRUE)
 
   ## pre-defined layout selections
   if(is.character(layout) == TRUE & length(layout) == 1) {
@@ -57,7 +59,7 @@ get_Layout <- function(
     if(layout == "empty") {
 
       layout = list(
-        
+
         ## empty Abanico plot -------------------------------------------------
         abanico = list(
           font.type = list(
