@@ -22,7 +22,7 @@
 #' @section Function version: 0.3.3
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [RLum.Data.Curve-class], [RLum.Data.Image-class],
 #'  [RLum.Data.Spectrum-class], [RLum.Analysis-class], [RLum.Results-class]
@@ -61,7 +61,6 @@ setGeneric("get_RLum", function (object, ...) {standardGeneric("get_RLum") })
 setMethod("get_RLum",
           signature = "list",
           function(object, class = NULL, null.rm = FALSE, ...){
-
             ##take care of the class argument
             if(!is.null(class)){
               sel <- class[1] == vapply(object, function(x) class(x), character(1))
@@ -71,14 +70,11 @@ setMethod("get_RLum",
               rm(sel)
             }
 
-
             ##make remove all non-RLum objects
             selection <- lapply(1:length(object), function(x){
-
               ##get rid of all objects that are not of type RLum, this is better than leaving that
               ##to the user
               if(inherits(object[[x]], what = "RLum")){
-
                 ##it might be the case the object already comes with empty objects, this would
                 ##cause a crash
                 if(inherits(object[[x]], "RLum.Analysis") && length(object[[x]]@records) == 0)
@@ -86,9 +82,7 @@ setMethod("get_RLum",
 
                 get_RLum(object[[x]], ...)
 
-
               } else {
-
                 warning(paste0("[get_RLum()] object #",x," in the list was not of type 'RLum' and has been removed!"),
                         call. = FALSE)
                 return(NULL)
@@ -99,31 +93,24 @@ setMethod("get_RLum",
 
             ##remove empty or NULL objects after the selection ... if wanted
             if(null.rm){
-
-
               ##first set all empty objects to NULL ... for RLum.Analysis objects
               selection <- lapply(1:length(selection), function(x){
-                if(inherits(selection[[x]], "RLum.Analysis") && length(selection[[x]]@records) == 0){
+                if(length(selection[[x]]) == 0 ||
+                   (inherits(selection[[x]], "RLum.Analysis") &&
+                    length(selection[[x]]@records) == 0))
                   return(NULL)
-
-                }else{
+                else
                   return(selection[[x]])
 
-                }
-
               })
-
               ##get rid of all NULL objects
-              selection <- selection[!sapply(selection, is.null)]
-
+              selection <- selection[!vapply(selection, is.null, logical(1))]
 
             }
-
             return(selection)
 
           })
 
-
 #' Method to handle NULL if the user calls get_RLum
 #'
 #' @describeIn get_RLum
