@@ -63,13 +63,13 @@
 #' @param subset `[subset]` [expression] (**required**):
 #' logical expression indicating elements or rows to keep, this function works
 #' in [Risoe.BINfileData-class] objects like [subset.data.frame], but takes care
-#' of the object structure
+#' of the object structure. Works also on [RLum.Analysis-class] objects.
 #'
 #' @param row.names [logical] (*with default*):
 #' enables or disables row names (`as.data.frame`)
 #'
 #' @param recursive [logical] (*with default*):
-#' enables or disables further subsetting (`unlist`)
+#' enables or disables further sub-setting (`unlist`)
 #'
 #' @param optional [logical] (*with default*):
 #' logical. If TRUE, setting row names and converting column names
@@ -149,7 +149,7 @@ hist.RLum.Results <- function(x, ...) plot_Histogram(data = x, ...)
 
 #' @rdname methods_RLum
 #' @export
-hist.RLum.Data.Image <- function(x, ...) hist(x =get_RLum(x)@data@values, ...)
+hist.RLum.Data.Image <- function(x, ...) hist(x = get_RLum(x), ...)
 
 #' @rdname methods_RLum
 #' @export
@@ -177,7 +177,7 @@ summary.RLum.Analysis <- function(object, ...) lapply(object@records, function(x
 #' @rdname methods_RLum
 #' @method summary RLum.Data.Image
 #' @export
-summary.RLum.Data.Image <- function(object, ...) summary(object@data@data@values)
+summary.RLum.Data.Image <- function(object, ...) summary(object@data)
 
 # summary.RLum.Data.Spectrum <- function(object, ...)
 
@@ -243,6 +243,13 @@ subset.RLum.Analysis <- function(x, subset = NULL, ...) {
 ####################################################################################################
 # methods for generic: bin()
 # ##################################################################################################
+
+#' @rdname methods_RLum
+#' @export
+bin <- function(x, ...) {
+  UseMethod("bin")
+}
+
 #' @rdname methods_RLum
 #' @export
 bin.RLum.Data.Curve <- function(x, bin_size = 2, ...) bin_RLum.Data(x, bin_size = bin_size)
@@ -292,7 +299,7 @@ dim.RLum.Data.Spectrum <- function(x) dim(as(x, "matrix"))
 rep.RLum <- function(x, ...) replicate_RLum(x, ...)
 
 ####################################################################################################
-# methods for generic: name()
+# methods for generic: names()
 # ##################################################################################################
 #' @rdname methods_RLum
 #' @export
