@@ -175,6 +175,8 @@ plot_KDE <- function(
   output = TRUE,
   ...
 ) {
+  .set_function_name("plot_KDE")
+  on.exit(.unset_function_name(), add = TRUE)
 
   ## check data and parameter consistency -------------------------------------
 
