@@ -57,7 +57,9 @@ plot_RLum.Results<- function(
   object,
   single = TRUE,
   ...
-){
+) {
+  .set_function_name("plot_RLum.Results")
+  on.exit(.unset_function_name(), add = TRUE)
 
   ##============================================================================##
   ## CONSISTENCY CHECK OF INPUT DATA
@@ -72,7 +74,7 @@ plot_RLum.Results<- function(
   ## SAFE AND RESTORE PLOT PARAMETERS ON EXIT
   ##============================================================================##
   par.old <- par(no.readonly = TRUE)
-  on.exit(suppressWarnings(par(par.old)))
+  on.exit(suppressWarnings(par(par.old)), add = TRUE)
 
   ##============================================================================##
   ## ... ARGUMENTS
@@ -1022,7 +1024,7 @@ plot_RLum.Results<- function(
       par(bty="n")
       boxplot(MC.n, horizontal = TRUE, add = TRUE, bty="n")
     } else {
-      on.exit(NULL)
+      on.exit(NULL, add = TRUE) # FIXME(mcol): seems unnecessary
     }
   }#EndOf::Case 5 - calc_AliqoutSize()
 
