@@ -137,7 +137,9 @@ read_BIN2R <- function(
   pattern = NULL,
   verbose = TRUE,
   ...
-){
+) {
+  .set_function_name("read_BIN2R")
+  on.exit(.unset_function_name(), add = TRUE)
 
   # Self Call -----------------------------------------------------------------------------------
   # Option (a): Input is a list, every element in the list will be treated as file connection
@@ -265,7 +267,7 @@ read_BIN2R <- function(
       close(con)
     }
   }
-  on.exit(expr = on_exit())
+  on.exit(expr = on_exit(), add = TRUE)
 
   ## check for URL and attempt download
   if(verbose)
