@@ -115,7 +115,10 @@ use_DRAC <- function(
   print_references = TRUE,
   citation_style = "text",
   ...
-){
+) {
+  .set_function_name("use_DRAC")
+  on.exit(.unset_function_name(), add = TRUE)
+
   ## TODO:
   ## (1) Keep the data set as unmodified as possible. Check structure and order of parameters
   ## for meaningful combination.
@@ -271,7 +274,7 @@ use_DRAC <- function(
       reply <- readline("Do you want to see the DRAC error message (Y/N)?")
       if (reply == "Y" || reply == "y" || reply == 1)
         cat(error_msg)
-    })
+    }, add = TRUE)
     # nocov end
 
     .throw_error("\n\t We got a response from the server, but it\n",
