@@ -1,6 +1,5 @@
 test_that("check function", {
   testthat::skip_on_cran()
-  local_edition(3)
 
   ##load data
   data(ExampleData.XSYG, envir = environment())
@@ -9,6 +8,8 @@ test_that("check function", {
   expect_error(
     apply_CosmicRayRemoval("error"),
     regexp = "An object of class 'character' is not supported as input; please read the manual!")
+  expect_error(apply_CosmicRayRemoval(TL.Spectrum, method = "error"),
+               "Unknown method for cosmic ray removal")
 
   ##run basic tests
   expect_silent(apply_CosmicRayRemoval(TL.Spectrum, method = "Pych"))
@@ -17,6 +18,9 @@ test_that("check function", {
   expect_output(apply_CosmicRayRemoval(TL.Spectrum, method = "Pych", MARGIN = 2, verbose = TRUE, plot = TRUE))
   expect_silent(apply_CosmicRayRemoval(TL.Spectrum, method = "Pych",
                                        method.Pych.smoothing = 2, method.Pych.threshold_factor = 2))
+  expect_silent(apply_CosmicRayRemoval(TL.Spectrum, method = "smooth.spline",
+                                       kind = "3RS3R", twiceit = TRUE,
+                                       spar = NULL, MARGIN = 1))
 
   ##construct objects for different tests
   RLum_list <- list(TL.Spectrum)
@@ -33,6 +37,4 @@ test_that("check function", {
   expect_error(apply_CosmicRayRemoval(RLum_list_mixed))
   expect_s4_class(apply_CosmicRayRemoval(RLum.Analysis_mixed), class = "RLum.Analysis")
   expect_type(apply_CosmicRayRemoval(RLum.Analysis_mixed_list), "list")
-
 })
-
