@@ -1,6 +1,12 @@
 test_that("Test internals", {
   testthat::skip_on_cran()
 
+  ## since below we are testing internal functions that use `.throw_error()`
+  ## and `.throw_warning()`, we need to treat this block as a function
+  ## definition and set the function name
+  .set_function_name("test")
+  on.exit(.unset_function_name(), add = TRUE)
+
   # .expand_parameters() ------------------------------------------------------
   ##create empty function ... reminder
   ##this is an internal function, the first object is always discarded, it
@@ -138,30 +144,40 @@ test_that("Test internals", {
   expect_equal(sum(unlist(t)), expected = 110)
 
   ## .throw_error() ---------------------------------------------------------
-  fun.int <- function() .throw_error("Error message")
+  fun.int <- function() {
+    .set_function_name("fun.int")
+    on.exit(.unset_function_name(), add = TRUE)
+    .throw_error("Error message")
+  }
   fun.ext <- function() fun.int()
+  fun.docall <- function() do.call(fun.ext, args = list())
+  fun.docall_do <- function() fun.docall()
   expect_error(fun.int(),
                "[fun.int()] Error message", fixed = TRUE)
   expect_error(fun.ext(),
                "[fun.int()] Error message", fixed = TRUE)
-
-  fun.int <- function() .throw_error("Error message", nframe = 2)
-  fun.ext <- function() fun.int()
-  expect_error(fun.ext(),
-               "[fun.ext()] Error message", fixed = TRUE)
+  expect_error(fun.docall(),
+               "[fun.int()] Error message", fixed = TRUE)
+  expect_error(fun.docall_do(),
+               "[fun.int()] Error message", fixed = TRUE)
 
   ## .throw_warning() -------------------------------------------------------
-  fun.int <- function() .throw_warning("Warning message")
+  fun.int <- function() {
+    .set_function_name("fun.int")
+    on.exit(.unset_function_name(), add = TRUE)
+    .throw_warning("Warning message")
+  }
   fun.ext <- function() fun.int()
+  fun.docall <- function() do.call(fun.ext, args = list())
+  fun.docall_do <- function() fun.docall()
   expect_warning(fun.int(),
                  "[fun.int()] Warning message", fixed = TRUE)
   expect_warning(fun.ext(),
                  "[fun.int()] Warning message", fixed = TRUE)
-
-  fun.int <- function() .throw_warning("Warning message", nframe = 2)
-  fun.ext <- function() fun.int()
-  expect_warning(fun.ext(),
-                 "[fun.ext()] Warning message", fixed = TRUE)
+  expect_warning(fun.docall(),
+                 "[fun.int()] Warning message", fixed = TRUE)
+  expect_warning(fun.docall_do(),
+                 "[fun.int()] Warning message", fixed = TRUE)
 
   ## SW() ------------------------------------------------------------------
   expect_silent(SW(cat("silenced message")))
