@@ -1,5 +1,3 @@
-context("plot_RLum.Data.Curve")
-
 test_that("Test the basic plot functionality", {
   testthat::skip_on_cran()
 
@@ -14,7 +12,8 @@ test_that("Test the basic plot functionality", {
   expect_error(plot_RLum.Data.Curve("temp"), regexp = "Input object is not of type RLum.Data.Curve")
 
   ## trigger warning
-  expect_warning(plot_RLum.Data.Curve(temp_NA), regexp = "Curve contains only NA-values, nothing plotted.")
+  expect_warning(expect_null(plot_RLum.Data.Curve(temp_NA)),
+                 "Curve contains only NA-values, nothing plotted")
   expect_warning(plot_RLum.Data.Curve(set_RLum("RLum.Data.Curve"), norm = TRUE), "Normalisation led to Inf or NaN values. Values replaced by 0")
 
   ## run function with various conditions
@@ -22,8 +21,15 @@ test_that("Test the basic plot functionality", {
   expect_silent(plot_RLum.Data.Curve(temp, norm = TRUE))
   expect_silent(plot_RLum.Data.Curve(temp, norm = "max"))
   expect_silent(plot_RLum.Data.Curve(temp, norm = "min"))
+  expect_silent(plot_RLum.Data.Curve(temp, norm = "last"))
   expect_silent(plot_RLum.Data.Curve(temp, norm = "huot"))
   expect_silent(plot_RLum.Data.Curve(temp, smooth = TRUE))
   expect_silent(plot_RLum.Data.Curve(temp, par.local = FALSE))
 
+  temp@recordType <- "OSL"
+  temp@info <- list(interval = 1)
+  expect_silent(plot_RLum.Data.Curve(temp))
+  temp@recordType <- "TL"
+  temp@info <- list(curveDescripter = "xlab;ylab", RATE = 2)
+  expect_silent(plot_RLum.Data.Curve(temp))
 })
