@@ -1,15 +1,28 @@
-test_that("test pure success of the plotting without warning or error", {
+data(ExampleData.XSYG, envir = environment())
+
+test_that("input validation", {
+  testthat::skip_on_cran()
+
+  expect_error(plot_RLum.Data.Spectrum("error"),
+               "'object' must be of type 'RLum.Data.Spectrum' or 'matrix'")
+  expect_error(plot_RLum.Data.Spectrum(TL.Spectrum, plot.type = "error"),
+               "Unknown plot type")
+  expect_error(plot_RLum.Data.Spectrum(TL.Spectrum, bg.spectrum = "error"),
+               "Input for 'bg.spectrum' not supported")
+  expect_error(plot_RLum.Data.Spectrum(TL.Spectrum, bin.cols = 0),
+               "'bin.cols' and 'bin.rows' have to be > 1")
+
+  expect_warning(plot_RLum.Data.Spectrum(TL.Spectrum, bg.channels = -2),
+                 "'bg.channels' out of range")
+})
+
+test_that("check functionality", {
   testthat::skip_on_cran()
-  local_edition(3)
 
     ##RLum.Data.Spectrum -------
-    data(ExampleData.XSYG, envir = environment())
     m <- TL.Spectrum@data
     bg.spectrum <- set_RLum(class = "RLum.Data.Spectrum", data = TL.Spectrum@data[,15:16, drop = FALSE])
 
-    ##crash the function with wrong input
-    expect_error(plot_RLum.Data.Spectrum(object = "test"),
-                 regexp = "Input object neither of class 'RLum.Data.Spectrum' nor 'matrix'.")
 
     ##try a matrix as input
     expect_message(plot_RLum.Data.Spectrum(object = m),
@@ -21,9 +34,14 @@ test_that("test pure success of the plotting without warning or error", {
     expect_message(plot_RLum.Data.Spectrum(object = m),
         regexp = "Input has been converted to a RLum.Data.Spectrum object using set_RLum()")
 
+    ## test duplicated column names
+    t <- TL.Spectrum
+    colnames(t@data) <- rep(50, ncol(t@data))
+    expect_warning(plot_RLum.Data.Spectrum(t),
+                   "Duplicated column names found")
 
     ##standard plot with some settings
-    expect_silent(plot(
+    expect_silent(plot_RLum.Data.Spectrum(
       TL.Spectrum,
       plot.type = "contour",
       main = "Test",
@@ -73,7 +91,7 @@ test_that("test pure success of the plotting without warning or error", {
       bg.spectrum = bg.spectrum,
       bin.rows = 10,
       bin.cols = 1
-    ), "\\[plot_RLum.Data.Spectrum\\(\\)\\] 6 channel\\(s\\) removed due to row \\(wavelength\\) binning.")
+    ), "6 channels removed due to row \\(wavelength\\) binning")
 
     ## check output and limit counts
     expect_type(suppressWarnings(plot_RLum.Data.Spectrum(
@@ -122,6 +140,18 @@ test_that("test pure success of the plotting without warning or error", {
       )
     ))
 
+    expect_silent(suppressWarnings(
+      plot_RLum.Data.Spectrum(
+        TL.Spectrum,
+        plot.type = "multiple.lines",
+        xlim = c(310, 750),
+        frames = c(1,3),
+        ylim = c(0, 100),
+        bin.rows = 10,
+        bin.cols = 1
+      )
+    ))
+
     ## plot: image ------------
     ### plot_image: standard -------
     expect_silent(suppressWarnings(
@@ -169,6 +199,18 @@ test_that("test pure success of the plotting without warning or error", {
         bin.cols = 6,
         contour = FALSE)))
 
+    ## test frames
+    expect_silent(suppressWarnings(
+      plot_RLum.Data.Spectrum(
+        TL.Spectrum,
+        plot.type = "single",
+        xlim = c(310, 750),
+        frames = 1,
+        ylim = c(0, 300),
+        bin.rows = 10,
+        bin.cols = 6,
+        contour = FALSE)))
+
     ### plot_image: colour changes -------
     expect_silent(suppressWarnings(
       plot_RLum.Data.Spectrum(
@@ -223,17 +265,9 @@ test_that("test pure success of the plotting without warning or error", {
       )
     ))
 
-
-    ##create more error
-    expect_error(plot(
-      TL.Spectrum,
-      plot.type = "contour",
-      xlim = c(310, 750),
-      ylim = c(0, 300),
-      bin.cols = 0
-    ))
-
-
-
+  ## more coverage
+  plot_RLum.Data.Spectrum(TL.Spectrum, plot.type = "multiple.lines",
+                          phi = 15, theta = -30, r = 10, log = "xyz",
+                          shade = 0.4, expand = 0.5, border = 1,
+                          axes = FALSE, norm = "min", col = 2)
 })
-
